==========================
The ``lino-amici`` package
==========================



.. image:: https://readthedocs.org/projects/lino/badge/?version=latest
    :alt: Documentation Status
    :target: http://lino.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/lino-framework/noi/badge.svg?branch=master
    :target: https://coveralls.io/github/lino-framework/noi?branch=master

.. image:: https://travis-ci.org/lino-framework/noi.svg?branch=stable
    :target: https://travis-ci.org/lino-framework/noi?branch=stable

.. image:: https://img.shields.io/pypi/v/lino-noi.svg
    :target: https://pypi.python.org/pypi/lino-noi/

.. image:: https://img.shields.io/pypi/l/lino-noi.svg
    :target: https://pypi.python.org/pypi/lino-noi/

Lino Amici is a customizable Lino application for managing family
contacts.  It is currently a submarine project, used only by its
author and therefore poorly documented.

- The central project homepage is http://amici.lino-framework.org

- For *introductions* and *commercial information* about Lino Amici
  please see `www.saffre-rumma.net
  <http://www.saffre-rumma.net>`__.



